@@ -2,7 +2,10 @@
 # -*- coding: utf-8 -*-
 
 import os
+import sys
 
+TRUE_BOOLEAN = ("YES", "Y")
+FALSE_BOOLEAN = ("NO", "N")
 
 def get_prog():
     return 'rider'
@@ -38,4 +41,19 @@ def get_terminal_size():
             pass
     if not cr:
         cr = (os.environ.get('LINES', 25), os.environ.get('COLUMNS', 80))
-    return int(cr[1]), int(cr[0])
\ No newline at end of file
+    return int(cr[1]), int(cr[0])
+
+
+def get_userinput(msg, retry=3):
+    for i in xrange(retry):
+        resp = raw_input(msg)
+        if resp.upper() in TRUE_BOOLEAN + FALSE_BOOLEAN:
+            break
+    else:
+        sys.stderr.write("The pagrant could been created due to the user's wrong input\n")
+        sys.exit(1)
+    return resp
+
+
+def is_true(value):
+    return value.upper() in TRUE_BOOLEAN
